@@ -11,7 +11,7 @@ use Moo;
 use namespace::clean;
 
 # Version.
-our $VERSION = 0.08;
+our $VERSION = 0.09;
 
 # Get XML.
 has xml => (
@@ -117,6 +117,8 @@ For more information about Sofia Map, click L<here|https://en.wikipedia.org/wiki
 
 =head1 EXAMPLE1
 
+=for comment filename=print_sofia_route.pl
+
  # Pragmas.
  use strict;
  use warnings;
@@ -139,6 +141,8 @@ For more information about Sofia Map, click L<here|https://en.wikipedia.org/wiki
 
 =head1 EXAMPLE2
 
+=for comment filename=print_sofia_def_xml_file.pl
+
  # Pragmas.
  use strict;
  use warnings;
@@ -160,6 +164,8 @@ For more information about Sofia Map, click L<here|https://en.wikipedia.org/wiki
 
 =head1 EXAMPLE3
 
+=for comment filename=print_sofia_image.pl
+
  # Pragmas.
  use strict;
  use warnings;
@@ -189,14 +195,16 @@ For more information about Sofia Map, click L<here|https://en.wikipedia.org/wiki
 
 =begin html
 
-<a href="https://raw.githubusercontent.com/tupinek/Map-Tube-Sofia/master/images/ex3.png">
-  <img src="https://raw.githubusercontent.com/tupinek/Map-Tube-Sofia/master/images/ex3.png" alt="Софийско метро" width="300px" height="300px" />
+<a href="https://raw.githubusercontent.com/tupinek/Map-Tube-Sofia/master/images/Sofia.png">
+  <img src="https://raw.githubusercontent.com/tupinek/Map-Tube-Sofia/master/images/Sofia.png" alt="Софийско метро" width="300px" height="300px" />
 </a>
 
 =end html
 
 =head1 EXAMPLE4
 
+=for comment filename=print_sofia_lines.pl
+
  # Pragmas.
  use strict;
  use warnings;
@@ -220,6 +228,8 @@ For more information about Sofia Map, click L<here|https://en.wikipedia.org/wiki
 
 =head1 EXAMPLE5
 
+=for comment filename=print_sofia_line_stations.pl
+
  # Pragmas.
  use strict;
  use warnings;
@@ -301,12 +311,12 @@ L<http://skim.cz>
 
 =head1 LICENSE AND COPYRIGHT
 
- © 2014-2017 Michal Josef Špaček
+ © 2014-2025 Michal Josef Špaček
  Artistic License
  BSD 2-Clause License
 
 =head1 VERSION
 
-0.08
+0.09
 
 =cut
